@@ -21,9 +21,9 @@ def subscribe(option, cb):
   resCall = requests.get(api_url + '/call/')
   resMessage = requests.get(api_url + '/message/')
 
-  cb(resInternet.json())
-  cb(resCall.json())
-  cb(resMessage.json())
+  cb('internet_init', resInternet.json())
+  cb('call_init', resCall.json())
+  cb('message_init', resMessage.json())
 
   consumer = KafkaConsumer(
     bootstrap_servers=kafka_url,
@@ -33,8 +33,9 @@ def subscribe(option, cb):
   consumer.subscribe(['internet_increase', 'call_increase', 'message_increase'])
   for msg in consumer:
     print('===============')
+    print(msg)
     print(msg.value)
     print(msg.value.decode('utf-8'))
-    cb(msg.value.decode('utf-8'))
+    cb('something_increase', msg.value.decode('utf-8'))
     print('===============')
     # assert isinstance(msg.value, dict)
\ No newline at end of file
